@@ -12,6 +12,7 @@
 #' }
 
 full_text_urls <- function(doi){
+  plos_check_dois(doi)
   makeurl <- function(x){
     doijournal <- strsplit(x, "\\.")[[1]][[3]]
     journal <- switch(doijournal,
@@ -66,7 +67,7 @@ plos_fulltext <- function(doi, ...){
     out <- httr::GET(x, ...)
     httr::warn_for_status(out)
     stopifnot(out$headers$`content-type` == 'text/xml')
-    httr::content(out, as = "text")
+    httr::content(out, as = "text", encoding = "UTF-8")
   }
   res <- lapply(urls, getfulltext)
   names(res) <- doi
